| extended-endpoints | R Documentation |
Functions for YouTube API endpoints that were not previously covered in tuber, including live streaming, thumbnails, channel sections, and modern video features.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.