Learn R Programming

tuber (version 1.4.1)

get_all_comments: Get all the comments for a video including replies

Description

Get all the comments for a video including replies

Usage

get_all_comments(video_id = NULL, max_results = NULL, ...)

Value

a data.frame with the following columns: authorDisplayName, authorProfileImageUrl, authorChannelUrl,

authorChannelId.value, videoId, textDisplay, canRate, viewerRating, likeCount, publishedAt, updatedAt, id, moderationStatus, parentId

Arguments

video_id

string; Required. video_id: video ID.

max_results

Integer. Maximum number of comments to return. Default is NULL which returns all comments. Set this to avoid long-running requests on popular videos.

...

Additional arguments passed to tuber_GET.

References

https://developers.google.com/youtube/v3/docs/commentThreads/list

Examples

Run this code
if (FALSE) {

# Set API token via yt_oauth() first

get_all_comments(video_id = "a-UQz7fqR3w")
get_all_comments(video_id = "a-UQz7fqR3w", max_results = 100)
}

Run the code above in your browser using DataLab