View source: R/get_playlist_items.R
| get_playlist_items | R Documentation |
Get Playlist Items
get_playlist_items(
filter = NULL,
part = "contentDetails",
max_results = 50,
video_id = NULL,
page_token = NULL,
simplify = TRUE,
...
)
filter |
string; Required.
named vector of length 1
potential names of the entry in the vector:
|
part |
Required. Comma separated string including one or more of the
following: |
max_results |
Maximum number of items that should be returned. Integer. Optional. Default is 50. If over 50, additional requests are made until the requested amount is retrieved. Larger values may increase API quota usage. |
video_id |
Optional. request should return only the playlist items that contain the specified video. |
page_token |
specific page in the result set that should be returned, optional |
simplify |
returns a data.frame rather than a list. |
... |
Additional arguments passed to |
playlist items
https://developers.google.com/youtube/v3/docs/playlistItems/list
## Not run:
# Set API token via yt_oauth() first
get_playlist_items(filter =
c(playlist_id = "PLrEnWoR732-CN09YykVof2lxdI3MLOZda"))
get_playlist_items(filter =
c(playlist_id = "PL0fOlXVeVW9QMO3GoESky4yDgQfK2SsXN"),
max_results = 51)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.