is_transient_error: Check if an error is transient and worth retrying

View source: R/error_handling.R

is_transient_errorR Documentation

Check if an error is transient and worth retrying

Description

Check if an error is transient and worth retrying

Usage

is_transient_error(error)

Arguments

error

Error object to check

Value

Logical indicating if error is transient


tuber documentation built on March 25, 2026, 9:08 a.m.