Learn R Programming

tuber (version 0.2)

list_abuse_report_reasons: List reasons that can be used to report abusive videos

Description

List reasons that can be used to report abusive videos

Usage

list_abuse_report_reasons()

Arguments

Value

  • data.frame with 3 columns: etag, label, secReasons

References

https://developers.google.com/youtube/v3/docs/videoAbuseReportReasons/list

Examples

Run this code
list_abuse_report_reasons()

Run the code above in your browser using DataLab