| safe_extract | R Documentation |
Extracts a field from an object, returning a default value if the field is missing or NULL.
safe_extract(obj, field, default = NA_character_)
obj |
Object to extract from |
field |
Field name (character) |
default |
Default value if field missing. Default: NA_character_ |
The field value or default
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.