| safe_nested | R Documentation |
Extracts a value from nested list structures, returning a default value if any level of the path is missing.
safe_nested(obj, ..., default = NA_character_)
obj |
Object to extract from |
... |
Field names in order (e.g., "author", "id", "value") |
default |
Default value if any field missing. Default: NA_character_ |
The nested field value or default
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.