Learn R Programming

tuber (version 2.0.0)

tuber_GET: GET

Description

GET

Usage

tuber_GET(
  path,
  query,
  auth = "token",
  use_cache = TRUE,
  cache_ttl = NULL,
  force_refresh = FALSE,
  ...
)

Value

list

Arguments

path

path to specific API request URL

query

query list

auth

A character vector of the authentication method, either "token" (the default) or "key"

use_cache

Logical. Whether eligible responses may be served from and stored in the tuber cache.

cache_ttl

Optional cache lifetime in seconds.

force_refresh

Logical. Ignore a cached response and refresh it.

...

Additional arguments passed to GET.