Skip to contents

Shows the metadata attributes added to tuber function results for debugging and quota management.

Usage

tuber_info(result)

Arguments

result

A result object from a tuber function with metadata attributes

Examples

if (FALSE) { # \dontrun{
result <- get_video_details("dQw4w9WgXcQ")
tuber_info(result)
} # }