A list of the response object from the POST, content,
and the URL of the video
Arguments
file
Filename of the caption file with timing information (e.g., `.srt`, `.vtt`).
As of April 12, 2024, timing information is required for all caption uploads.
video_id
YouTube Video ID. Try list_my_videos for examples.