Adds consistent metadata attributes to function return values for better debugging and quota management.
add_tuber_attributes(
result,
api_calls_made = 1,
quota_used = NULL,
function_name = NULL,
parameters = list(),
timestamp = Sys.time(),
...
)The result object with standardized attributes added
The result object to add attributes to
Number of API calls made to generate this result
Estimated quota units consumed
Name of the calling function
List of key parameters used in the function call
When the API call was made
Additional custom attributes