Learn R Programming

tuber (version 2.0.0)

extended-endpoints: Extended YouTube API Endpoints

Description

Functions for YouTube API endpoints that were not previously covered in tuber, including live streaming, thumbnails, channel sections, and modern video features.

Arguments