View source: R/get_all_channel_video_stats.R
| get_all_channel_video_stats | R Documentation |
Efficiently collects all video IDs from a channel's uploads playlist, then fetches statistics and details using batch processing for optimal API quota usage.
get_all_channel_video_stats(channel_id = NULL, mine = FALSE, ...)
channel_id |
Character. Id of the channel |
mine |
Boolean. TRUE if you want to fetch stats of your own channel. Default is FALSE. |
... |
Additional arguments passed to |
A data.frame containing video metadata along with view, like,
dislike and comment counts.
If the channel_id is mistyped or there is no information, an empty list is returned
https://developers.google.com/youtube/v3/docs/channels/list
## Not run:
# Set API token via yt_oauth() first
get_all_channel_video_stats(channel_id="UCxOhDvtaoXDAB336AolWs3A")
get_all_channel_video_stats(channel_id="UCMtFAi84ehTSYSE9Xo") # Incorrect channel ID
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.