Learn R Programming

tuber (version 1.4.1)

get_live_chat_messages: Get Live Chat Messages

Description

Retrieves live chat messages for a specific live chat. Note that live chat messages can only be retrieved for active live broadcasts.

Usage

get_live_chat_messages(
  live_chat_id,
  part = "snippet,authorDetails",
  hl = NULL,
  max_results = 500,
  page_token = NULL,
  profile_image_size = NULL,
  simplify = TRUE,
  ...
)

Value

A data.frame or list of live chat messages.

Arguments

live_chat_id

Character. The id of the live chat.

part

Character. Parts to retrieve. Valid values are "snippet", "authorDetails". Default is "snippet,authorDetails".

hl

Character. Language used for text values. Optional.

max_results

Integer. Maximum number of items to return. Default is 500. Max is 2000.

page_token

Character. Specific page token to retrieve. Optional.

profile_image_size

Integer. Size of the profile image to return. Optional.

simplify

Logical. Whether to return a simplified data.frame. Default is TRUE.

...

Additional arguments passed to tuber_GET.

References

https://developers.google.com/youtube/v3/live/docs/liveChatMessages/list

Examples

Run this code
if (FALSE) {
# Set API token via yt_oauth() first

messages <- get_live_chat_messages(live_chat_id = "Cg0KC...")
}

Run the code above in your browser using DataLab