powered by
Retrieves statistics for one or more videos and always returns one row per video found.
get_video_stats( video_ids, include_content_details = FALSE, batch_size = 50, auth = "key", ... )
A data frame with snake-case column names and one row per video. Count columns are numeric and missing statistics are returned as `NA`.
Character vector of YouTube video IDs.
Include duration, definition, dimension, licensed-content, and projection fields.
Number of video IDs per API request, up to 50.
Authentication method, `"token"` or `"key"`.
Additional arguments passed to [tuber_GET()].
https://developers.google.com/youtube/v3/docs/videos/list
if (FALSE) { get_video_stats("N708P-A45D0") get_video_stats(c("N708P-A45D0", "M7FIvfx5J10"), auth = "key") }
Run the code above in your browser using DataLab