Learn R Programming

tuber (version 2.0.0)

is_transient_error: Check if an error is transient and worth retrying

Description

Check if an error is transient and worth retrying

Usage

is_transient_error(error)

Value

Logical indicating if error is transient

Arguments

error

Error object to check