powered by
Retrieves live chat messages for a specific live chat. Note that live chat messages can only be retrieved for active live broadcasts.
list_live_chat_messages( live_chat_id, part = "snippet,authorDetails", language = NULL, max_results = 500, page_token = NULL, profile_image_size = NULL, simplify = TRUE, ... )
A data.frame or list of live chat messages.
Character. The id of the live chat.
Character. Parts to retrieve. Valid values are "snippet", "authorDetails". Default is "snippet,authorDetails".
Optional language code for localized text.
Maximum total number of messages to return.
Character. Specific page token to retrieve. Optional.
Integer. Size of the profile image to return. Optional.
Logical. Whether to return a simplified data.frame. Default is TRUE.
Additional arguments passed to tuber_GET.
tuber_GET
https://developers.google.com/youtube/v3/live/docs/liveChatMessages/list
if (FALSE) { # Set API token via yt_oauth() first messages <- list_live_chat_messages(live_chat_id = "Cg0KC...") }
Run the code above in your browser using DataLab