Sets the moderation status of one or more comments. Requires OAuth 2.0 authentication and owner privileges.
Arguments
- comment_id
Character vector. The IDs of the comments to update.
- moderation_status
Character. Valid values are 'heldForReview', 'published', 'rejected'.
Logical. Whether to ban the author from commenting on the channel. Optional.
- ...
Additional arguments passed to
tuber_POST_json.