View source: R/comments_write.R
| set_comment_moderation_status | R Documentation |
Sets the moderation status of one or more comments. Requires OAuth 2.0 authentication and owner privileges.
set_comment_moderation_status(
comment_id,
moderation_status,
ban_author = FALSE,
...
)
comment_id |
Character vector. The IDs of the comments to update. |
moderation_status |
Character. Valid values are 'heldForReview', 'published', 'rejected'. |
ban_author |
Logical. Whether to ban the author from commenting on the channel. Optional. |
... |
Additional arguments passed to |
A list containing the API response.
https://developers.google.com/youtube/v3/docs/comments/setModerationStatus
## Not run:
# Set API token via yt_oauth() first
set_comment_moderation_status(comment_id = "Ugz...", moderation_status = "rejected")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.