powered by
Sets the moderation status of one or more comments. Requires OAuth 2.0 authentication and owner privileges.
set_comment_moderation_status( comment_id, moderation_status, ban_author = FALSE, ... )
A list containing the API response.
Character vector. The IDs of the comments to update.
Character. Valid values are 'heldForReview', 'published', 'rejected'.
Logical. Whether to ban the author from commenting on the channel. Optional.
Additional arguments passed to tuber_POST_json.
tuber_POST_json
https://developers.google.com/youtube/v3/docs/comments/setModerationStatus
if (FALSE) { # Set API token via yt_oauth() first set_comment_moderation_status(comment_id = "Ugz...", moderation_status = "rejected") }
Run the code above in your browser using DataLab