Learn R Programming

tuber (version 2.0.0)

tuber-package: tuber: Client for the YouTube Data API

Description

Search public YouTube data and retrieve channels, videos, playlists, comments, captions, live broadcasts, and reference data. Authenticated methods support common uploads, playlist changes, comment moderation, and media updates. See the YouTube Data API documentation at https://developers.google.com/youtube/v3/.

Arguments

Author

Maintainer: Gaurav Sood gsood07@gmail.com

Authors:

Other contributors:

See Also