GET
tuber_GET(
path,
query,
auth = "token",
use_cache = TRUE,
cache_ttl = NULL,
force_refresh = FALSE,
...
)list
path to specific API request URL
query list
A character vector of the authentication method, either "token" (the default) or "key"
Logical. Whether eligible responses may be served from and stored in the tuber cache.
Optional cache lifetime in seconds.
Logical. Ignore a cached response and refresh it.
Additional arguments passed to GET.