Shows the metadata attributes added to tuber function results for debugging and quota management.
Examples
if (FALSE) { # \dontrun{
result <- get_video_details("dQw4w9WgXcQ")
tuber_info(result)
} # }
Shows the metadata attributes added to tuber function results for debugging and quota management.
if (FALSE) { # \dontrun{
result <- get_video_details("dQw4w9WgXcQ")
tuber_info(result)
} # }