tuber_info: Display tuber function metadata

View source: R/tuber.R

tuber_infoR Documentation

Display tuber function metadata

Description

Shows the metadata attributes added to tuber function results for debugging and quota management.

Usage

tuber_info(result)

Arguments

result

A result object from a tuber function with metadata attributes

Examples

## Not run: 
result <- get_video_details("dQw4w9WgXcQ")
tuber_info(result)

## End(Not run)

tuber documentation built on March 25, 2026, 9:08 a.m.