| tuber_info | R Documentation |
Shows the metadata attributes added to tuber function results for debugging and quota management.
tuber_info(result)
result |
A result object from a tuber function with metadata attributes |
## Not run:
result <- get_video_details("dQw4w9WgXcQ")
tuber_info(result)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.