powered by
Shows the metadata attributes added to tuber function results for debugging and quota management.
tuber_info(result)
A result object from a tuber function with metadata attributes
if (FALSE) { result <- get_video_details("dQw4w9WgXcQ") tuber_info(result) }
Run the code above in your browser using DataLab