Learn R Programming

tuber (version 1.4.1)

tuber_info: Display tuber function metadata

Description

Shows the metadata attributes added to tuber function results for debugging and quota management.

Usage

tuber_info(result)

Arguments

result

A result object from a tuber function with metadata attributes

Examples

Run this code
if (FALSE) {
result <- get_video_details("dQw4w9WgXcQ")
tuber_info(result)
}

Run the code above in your browser using DataLab