powered by
Updates selected mutable video fields while preserving the other fields in each requested YouTube resource part. At least one field must be supplied.
update_video_metadata( video_id, title = NULL, category_id = NULL, description = NULL, tags = NULL, default_language = NULL, privacy_status = NULL, made_for_kids = NULL, contains_synthetic_media = NULL, embeddable = NULL, license = NULL, public_stats_viewable = NULL, publish_at = NULL, on_behalf_of_content_owner = NULL, ... )
The updated video resource.
YouTube video ID.
Optional title.
Optional video-category ID.
Optional description. Use `""` to clear it.
Optional character vector of tags. Use `character()` to clear existing tags.
Optional default language.
Optional privacy status: `"private"`, `"public"`, or `"unlisted"`.
Optional self-declared made-for-kids setting.
Optional synthetic-media disclosure.
Optional embeddable setting.
Optional license, `"creativeCommon"` or `"youtube"`.
Optional public-statistics setting.
Optional RFC 3339 publication time. YouTube requires a private video that has never been published.
Optional YouTube content-owner ID. This is only available to authorized YouTube content partners.
Additional arguments passed to [get_video_details()] and [tuber_PUT()].
<https://developers.google.com/youtube/v3/docs/videos/update>
if (FALSE) { update_video_metadata( video_id = "VIDEO_ID", title = "New Video Title", privacy_status = "unlisted" ) }
Run the code above in your browser using DataLab