Learn R Programming

tuber (version 2.0.0)

yt_get_quota_usage: Get Current Quota Usage

Description

Returns session-local estimated quota usage for the current quota day. Actual project usage is available in the Google Cloud Console.

Usage

yt_get_quota_usage()

Arguments

Value

A data frame with one row per quota bucket and columns for estimated usage, configured limits, remaining quota, and reset time.

Examples

Run this code
if (FALSE) {
quota_status <- yt_get_quota_usage()
quota_status[quota_status$bucket == "data", ]
}

Run the code above in your browser using DataLab